@@ -3,17 +3,17 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
  */
- 
+
 #include <gtk/gtk.h>
 #include <libnotify/notify.h>
 #include <gst/gst.h>
@@ -23,6 +23,7 @@ NotifyNotification *notify;
 GstElement *play;
 GTimeVal current_time;
 gint sound_ref, count_play;
+GstBus *bus;
 
 gboolean fade_enabled;
 gboolean running_snooze;
@@ -30,4 +31,4 @@ gboolean running_snooze;
 void
 run_alarm(gchar *name);
 
-GKeyFile *alarm;
+GKeyFile *alarm_file;
