@@ -17,8 +17,8 @@
 #include <gtk/gtk.h>
 
 GKeyFile *loaded_alarms;
-
 gboolean need_check_first;
+gboolean blocked;
 
 void
 alarm_thread(void);
@@ -27,7 +27,7 @@ void
 reload_alarms(void);
 
 void
-update_alarm_thread(void);
+update_alarm_thread(gboolean thread);
 
 void
 process_alarm_thread(void);
