@@ -15,12 +15,31 @@
  */
 
 #include <gtk/gtk.h>
-
+#include <config.h>
+#ifndef APPINDICATOR
 GtkStatusIcon *status_icon;
+#endif
 
+#ifdef APPINDICATOR
+#include <libappindicator/app-indicator.h>
+
+AppIndicator *indicator;
+#endif
+
+guint context_id;
 
 void
 create_status_icon(void);
 
+#ifndef APPINDICATOR
 void
 change_birthday_status(gboolean on);
+
+void
+set_status_tooltip(gchar *tooltip);
+#endif
+
+#ifdef APPINDICATOR
+void
+change_birthday_status(gboolean on, gchar *text);
+#endif
